/*
 * Copyright 2020 Vincenzo De Notaris
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package com.vdenotaris.spring.boot.security.saml.web.controllers;

import com.vdenotaris.spring.boot.security.saml.web.ssl.RSA;
import com.vdenotaris.spring.boot.security.saml.web.stereotypes.CurrentUser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.User;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.security.spec.InvalidKeySpecException;

@Controller
public class LandingController {

    @Value("${frServerUrl}")
    private String frServerUrl;
    @Value("${paramName}")
    public String paramName;
    @Value("${publicKey}")
    public String publicKey;
	
	// Logger
	private static final Logger LOG = LoggerFactory.getLogger(LandingController.class);

    @RequestMapping("/landing")
    public void landing(@CurrentUser User user, HttpServletRequest request, HttpServletResponse response) throws IOException, InvalidKeySpecException, NoSuchAlgorithmException {
        Authentication auth = SecurityContextHolder.getContext().getAuthentication();
        if (auth == null)
            LOG.debug("Current authentication instance from security context is null");
        else
            LOG.debug("Current authentication instance from security context: " + this.getClass().getSimpleName());
        Object redirectUri = request.getSession().getAttribute("redirectUri");
        String url = this.frServerUrl;
        if (redirectUri != null) {
            url = (String) redirectUri;
        }
        url = setURLParam(url, encryptUsername(user.getUsername()));
        LOG.debug("fr-sp-saml-LandingController--Landing Redirect URL:" + url);
        response.sendRedirect(url);
    }

    /**
     * 处理请求url加入token参数
     *
     * @param url
     * @return
     */
    private String setURLParam(String url, String paramValue) {
        if (url.contains("?")) {
            return url + "&" + paramName + "=" + paramValue + "&state=saml";
        }
        return url + "?" + paramName + "=" + paramValue + "&state=saml";
    }

    private String encryptUsername(String username) throws InvalidKeySpecException, NoSuchAlgorithmException {
        return RSA.publicEncrypt(System.currentTimeMillis() + "#" + username, RSA.getPublicKey(publicKey));
    }
}
