 /*
  * Copyright (C), 2018-2021
  * Project: dev
  * FileName: SAMLEntryPointSub
  * Author:   Louis
  * Date:     2021/4/20 21:48
  */
 package com.vdenotaris.spring.boot.security.saml.web.core;

 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.security.core.AuthenticationException;
 import org.springframework.security.saml.SAMLEntryPoint;
 import org.springframework.security.web.FilterInvocation;

 import javax.servlet.FilterChain;
 import javax.servlet.ServletException;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 import javax.servlet.http.HttpSession;
 import java.io.IOException;

 /**
  * <Function Description><br>
  * <SAMLEntryPointSub>
  *
  * @author Louis
  * @since 1.0.0
  */
 public class SAMLEntryPointSub extends SAMLEntryPoint {
     private static final Logger LOG = LoggerFactory.getLogger(SAMLEntryPointSub.class);

     @Override
     public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
         FilterInvocation fi = new FilterInvocation(request, response, chain);
         if (!this.processFilter(fi.getRequest())) {
             chain.doFilter(request, response);
         } else {
             this.commence(fi.getRequest(), fi.getResponse(), (AuthenticationException) null);
         }
         // 存储跳转路径
         String redirectUri = request.getParameter("redirectUri");
         if (StringUtils.isNotBlank(redirectUri)) {
             try {
                 HttpSession session = fi.getHttpRequest().getSession(true);
                 session.setAttribute("redirectUri", redirectUri);
             } catch (Exception e) {
                 LOG.error(e.getMessage(), e);
             }
         }
     }
 }